@@ -167,16 +167,43 @@ def lab_to_xyz(c):
     return xyzd65
 
 
+def srgb_to_xyz(c):
+    c = np.array(c)
+    lrgb = srgb_to_lrgb(c)
+    xyz = lrgb_to_xyz(lrgb)
+    return xyz
+
+def srgb_to_lab(c):
+    c = np.array(c)
+
+    xyz = srgb_to_xyz(c)
+    lab = xyz_to_lab(xyz)
+    return lab
+
+def xyz_to_srgb(c):
+    c = np.array(c)
+    lrgb = xyz_to_lrgb(c)
+    srgb = lrgb_to_srgb(lrgb)
+    return srgb
+
+def lab_to_srgb(c):
+    c = np.array(c)
+    xyz = lab_to_xyz(c)
+    srgb = xyz_to_srgb(xyz)
+    return srgb
+
+#
 # if __name__ == '__main__':
-#     tmp = srgb_to_lrgb(np.array([1, 0, 0]))
-#     print(tmp)
-#     tmp = lrgb_to_xyz(tmp)
-#     print(tmp)
-#     tmp = xyz_to_lab(tmp)
-#     print(tmp)
-#     tmp = lab_to_xyz(tmp)
-#     print(tmp)
-#     tmp = xyz_to_lrgb(tmp)
-#     print(tmp)
-#     tmp = lrgb_to_srgb(tmp)
+#     # print (np.array([0.12156863, 0.46666667, 0.70588235]))
+#     tmp = srgb_to_lab([0.12156863, 0.46666667, 0.70588235])
 #     print(tmp)
+#     # tmp = lrgb_to_xyz(tmp)
+#     # print(tmp)
+#     # tmp = xyz_to_lab(tmp)
+#     # print(tmp)
+#     # tmp = lab_to_xyz(tmp)
+#     # print(tmp)
+#     # tmp = xyz_to_lrgb(tmp)
+#     # print(tmp)
+#     # tmp = lrgb_to_srgb(tmp)
+#     # print(tmp)
